@@ -26,14 +26,24 @@ class CheckRoleRequest(RpcRequest):
 		RpcRequest.__init__(self, 'hbr', '2017-09-08', 'CheckRole','hbr')
 		self.set_protocol_type('https')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_CheckRoleType(self):
+	def get_CheckRoleType(self): # String
 		return self.get_query_params().get('CheckRoleType')
 
-	def set_CheckRoleType(self,CheckRoleType):
-		self.add_query_param('CheckRoleType',CheckRoleType)
\ No newline at end of file
+	def set_CheckRoleType(self, CheckRoleType):  # String
+		self.add_query_param('CheckRoleType', CheckRoleType)
+	def get_CrossAccountRoleName(self): # String
+		return self.get_query_params().get('CrossAccountRoleName')
+
+	def set_CrossAccountRoleName(self, CrossAccountRoleName):  # String
+		self.add_query_param('CrossAccountRoleName', CrossAccountRoleName)
+	def get_CrossAccountUserId(self): # Long
+		return self.get_query_params().get('CrossAccountUserId')
+
+	def set_CrossAccountUserId(self, CrossAccountUserId):  # Long
+		self.add_query_param('CrossAccountUserId', CrossAccountUserId)
