@@ -25,14 +25,14 @@ class DescribeRegionsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'hbr', '2017-09-08', 'DescribeRegions','hbr')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_NeedVaultCount(self):
+	def get_NeedVaultCount(self): # Boolean
 		return self.get_query_params().get('NeedVaultCount')
 
-	def set_NeedVaultCount(self,NeedVaultCount):
-		self.add_query_param('NeedVaultCount',NeedVaultCount)
\ No newline at end of file
+	def set_NeedVaultCount(self, NeedVaultCount):  # Boolean
+		self.add_query_param('NeedVaultCount', NeedVaultCount)
